package atomfeed

import (
	"errors"
	"fmt"
)

type Link struct {
	*CommonAttributes
	Title    *Text       `xml:"title,attr,omitempty"`
	Content  *Content    `xml:"content"`
	Href     URI         `xml:"href,attr"`
	Rel      string      `xml:"rel,attr,omitempty"`
	Type     MediaType   `xml:"type,attr,omitempty"`
	HrefLang LanguageTag `xml:"hreflang,attr,omitempty"`
	Length   uint        `xml:"length,attr,omitempty"`
}

func (l *Link) Check() error {
	if l.Href == "" {
		return errors.New("href attribute of link empty")
	}

	if l.Title != nil {
		if err := (*l.Title).Check(); err != nil {
			return fmt.Errorf("title attribute of link %v: %v", l.Href, err)
		}
	}

	if l.Content == nil {
		return fmt.Errorf("no content element of link %v", l.Href)
	} else {
		if err := (*l.Content).Check(); err != nil {
			return fmt.Errorf("content element of link %v: %v", l.Href, err)
		}
	}

	return nil
}
